@@ -28,10 +28,10 @@ static void gail_button_factory_class_init (
 static AtkObject* gail_button_factory_create_accessible (
                                 GObject                       *obj);
 
-static AtkObjectFactoryClass    *parent_class = NULL;
+static GType gail_button_factory_get_accessible_type (void);
 
 GType
-gail_button_factory_get_type ()
+gail_button_factory_get_type (void)
 {
   static GType type = 0;
 
@@ -62,21 +62,10 @@ gail_button_factory_class_init (GailButtonFactoryClass *klass)
 {
   AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);
 
-  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);
-
   class->create_accessible = gail_button_factory_create_accessible;
+  class->get_accessible_type = gail_button_factory_get_accessible_type;
 }
 
-
-AtkObjectFactory* gail_button_factory_new ()
-{
-  GObject *factory;
-
-  factory = g_object_new (GAIL_TYPE_BUTTON_FACTORY, NULL);
-
-  return ATK_OBJECT_FACTORY (factory);
-} 
-
 static AtkObject* 
 gail_button_factory_create_accessible (GObject     *obj)
 {
@@ -88,3 +77,9 @@ gail_button_factory_create_accessible (GObject     *obj)
 
   return gail_button_new (widget);
 }
+
+static GType
+gail_button_factory_get_accessible_type (void)
+{
+  return GAIL_TYPE_BUTTON;
+}
