@@ -146,6 +146,11 @@ gail_container_ref_child (AtkObject *obj,
 
   children = gtk_container_children (GTK_CONTAINER(widget));
   tmp_list = g_list_nth (children, i);
+  if (!tmp_list)
+    {
+      g_list_free (children);
+      return NULL;
+    }  
   accessible = gtk_widget_get_accessible (GTK_WIDGET (tmp_list->data));
 
   g_list_free (children);
@@ -204,6 +209,7 @@ gail_container_real_initialize (AtkObject *obj,
                                 gpointer  data)
 {
   GailContainer *container = GAIL_CONTAINER (obj);
+  guint handler_id;
 
   ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
 
@@ -213,16 +219,18 @@ gail_container_real_initialize (AtkObject *obj,
    * We store the handler ids for these signals as some objects, e.g.
    * GailButton need to remove these handlers.
    */
-  container->add_handler =
-      g_signal_connect (data,
-                        "add",
-                        G_CALLBACK (gail_container_add_gtk),
-                        NULL);
-  container->remove_handler =
-      g_signal_connect (data,
-                        "remove",
-                        G_CALLBACK (gail_container_remove_gtk),
-                        NULL);
+  handler_id = g_signal_connect (data,
+                                 "add",
+                                 G_CALLBACK (gail_container_add_gtk),
+                                 NULL);
+  g_object_set_data (G_OBJECT (obj), "gail-add-handler-id", 
+                     GUINT_TO_POINTER (handler_id));
+  handler_id = g_signal_connect (data,
+                                 "remove",
+                                 G_CALLBACK (gail_container_remove_gtk),
+                                 NULL);
+  g_object_set_data (G_OBJECT (obj), "gail-remove-handler-id", 
+                     GUINT_TO_POINTER (handler_id));
 }
 
 static void
