@@ -30,7 +30,7 @@ static AtkObject* gail_container_factory_create_accessible (
 static GType gail_container_factory_get_accessible_type (void);
 
 GType
-gail_container_factory_get_type ()
+gail_container_factory_get_type (void)
 {
   static GType type = 0;
 
@@ -66,16 +66,6 @@ gail_container_factory_class_init (GailContainerFactoryClass *klass)
   class->get_accessible_type = gail_container_factory_get_accessible_type;
 }
 
-AtkObjectFactory* 
-gail_container_factory_new ()
-{
-  GObject *factory;
-
-  factory = g_object_new (GAIL_TYPE_CONTAINER_FACTORY, NULL);
-
-  return ATK_OBJECT_FACTORY (factory);
-} 
-
 static AtkObject* 
 gail_container_factory_create_accessible (GObject   *obj)
 {
