@@ -568,12 +568,6 @@ gail_entry_get_default_attributes (AtkText *text)
 
   entry = GTK_ENTRY (widget);
 
-  at_set = gail_misc_add_attribute (at_set,
-                                    ATK_TEXT_ATTR_JUSTIFICATION,
-     g_strdup (atk_text_attribute_get_value (ATK_TEXT_ATTR_JUSTIFICATION, 0)));
-  at_set = gail_misc_add_attribute (at_set,
-                                    ATK_TEXT_ATTR_WRAP_MODE,
-          g_strdup (atk_text_attribute_get_value (ATK_TEXT_ATTR_WRAP_MODE, 0)));
   at_set = gail_misc_get_default_attributes (at_set,
                                              gtk_entry_get_layout (entry),
                                              widget);
