@@ -22,7 +22,7 @@
 
 #include <gtk/gtkaccessible.h>
 #include <gail/gailwidget.h>
-#include <gail/gailtexthelper.h>
+#include <util/gailtextutil.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -42,7 +42,7 @@ struct _GailLabel
 {
   GailWidget parent;
 
-  GailTextHelper *texthelper;
+  GailTextUtil   *textutil;
   gint           cursor_position;
   gint           selection_bound;
   gint           label_length;
