@@ -82,7 +82,8 @@ gail_menu_new (GtkWidget *widget)
   atk_object_initialize (accessible, widget);
 
   accessible->role = ATK_ROLE_MENU;
-  accessible->layer = ATK_LAYER_POPUP;
+  g_object_set_data (G_OBJECT (accessible), "atk-component-layer",
+		     GINT_TO_POINTER (ATK_LAYER_POPUP));
 
   return accessible;
 }
