@@ -28,10 +28,10 @@ static void gail_menu_shell_factory_class_init (
 static AtkObject* gail_menu_shell_factory_create_accessible (
                                 GObject                         *obj);
 
-static AtkObjectFactoryClass    *parent_class = NULL;
+static GType gail_menu_shell_factory_get_accessible_type (void);
 
 GType
-gail_menu_shell_factory_get_type ()
+gail_menu_shell_factory_get_type (void)
 {
   static GType type = 0;
 
@@ -62,18 +62,8 @@ gail_menu_shell_factory_class_init (GailMenuShellFactoryClass *klass)
 {
   AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);
 
-  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);
-
   class->create_accessible = gail_menu_shell_factory_create_accessible;
-}
-
-AtkObjectFactory* gail_menu_shell_factory_new ()
-{
-  GObject *factory;
-
-  factory = g_object_new (GAIL_TYPE_MENU_SHELL_FACTORY, NULL);
-
-  return ATK_OBJECT_FACTORY (factory);
+  class->get_accessible_type = gail_menu_shell_factory_get_accessible_type;
 }
 
 static AtkObject*
@@ -86,3 +76,9 @@ gail_menu_shell_factory_create_accessible (GObject     *obj)
   widget = GTK_WIDGET (obj);
   return gail_menu_shell_new (widget);
 }
+
+static GType
+gail_menu_shell_factory_get_accessible_type (void)
+{
+  return GAIL_TYPE_MENU_SHELL;
+}
