@@ -28,10 +28,10 @@ static void gail_radio_button_factory_class_init (
 static AtkObject* gail_radio_button_factory_create_accessible (
                                 GObject                             *obj);
 
-static AtkObjectFactoryClass    *parent_class = NULL;
+static GType gail_radio_button_factory_get_accessible_type (void);
 
 GType
-gail_radio_button_factory_get_type ()
+gail_radio_button_factory_get_type (void)
 {
   static GType type = 0;
 
@@ -62,20 +62,10 @@ gail_radio_button_factory_class_init (GailRadioButtonFactoryClass *klass)
 {
   AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);
 
-  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);
-
   class->create_accessible = gail_radio_button_factory_create_accessible;
+  class->get_accessible_type = gail_radio_button_factory_get_accessible_type;
 }
 
-AtkObjectFactory* gail_radio_button_factory_new ()
-{
-  GObject *factory;
-
-  factory = g_object_new (GAIL_TYPE_RADIO_BUTTON_FACTORY, NULL);
-
-  return ATK_OBJECT_FACTORY (factory);
-} 
-
 static AtkObject* 
 gail_radio_button_factory_create_accessible (GObject     *obj)
 {
@@ -86,3 +76,9 @@ gail_radio_button_factory_create_accessible (GObject     *obj)
   widget = GTK_WIDGET (obj);
   return gail_radio_button_new (widget);
 }
+
+static GType
+gail_radio_button_factory_get_accessible_type (void)
+{
+  return GAIL_TYPE_RADIO_BUTTON;
+}
