@@ -27,7 +27,6 @@ static gint         gail_scrollbar_get_index_in_parent (AtkObject *accessible);
 
 static GailRangeClass *parent_class = NULL;
 
-
 GType
 gail_scrollbar_get_type (void)
 {
@@ -59,13 +58,10 @@ static void
 gail_scrollbar_class_init (GailScrollbarClass *klass)
 {
   AtkObjectClass *class = ATK_OBJECT_CLASS (klass);
-  GailWidgetClass *widget_class;
-
-  widget_class = (GailWidgetClass*)klass;
 
   class->get_index_in_parent = gail_scrollbar_get_index_in_parent;
 
-  parent_class = g_type_class_ref (GAIL_TYPE_RANGE);
+  parent_class = g_type_class_peek_parent (klass);
 }
 
 AtkObject* 
@@ -78,9 +74,8 @@ gail_scrollbar_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_SCROLLBAR, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
 
   accessible->role = ATK_ROLE_SCROLL_BAR;
 
