@@ -27,8 +27,8 @@ static G_CONST_RETURN gchar* gail_statusbar_get_name   (AtkObject          *obj)
 static gint         gail_statusbar_get_n_children      (AtkObject          *obj);
 static AtkObject*   gail_statusbar_ref_child           (AtkObject          *obj,
                                                         gint               i);
-static void         gail_statusbar_real_init           (GailWidget         *widget,
-                                                        GtkWidget          *gtk_widget);
+static void         gail_statusbar_real_initialize     (AtkObject          *obj,
+                                                        gpointer           data);
 
 static gint        gail_statusbar_notify               (GObject            *obj,
                                                         GParamSpec         *pspec,
@@ -67,17 +67,13 @@ static void
 gail_statusbar_class_init (GailStatusbarClass *klass)
 {
   AtkObjectClass  *class = ATK_OBJECT_CLASS (klass);
-  GailWidgetClass *widget_class;
 
-  widget_class = (GailWidgetClass*)klass;
-
-  parent_class = g_type_class_ref (GAIL_TYPE_CONTAINER);
+  parent_class = g_type_class_peek_parent (klass);
 
   class->get_name = gail_statusbar_get_name;
   class->get_n_children = gail_statusbar_get_n_children;
   class->ref_child = gail_statusbar_ref_child;
-
-  widget_class->init = gail_statusbar_real_init;
+  class->initialize = gail_statusbar_real_initialize;
 }
 
 AtkObject* 
@@ -90,9 +86,9 @@ gail_statusbar_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_STATUSBAR, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
+
   accessible->role = ATK_ROLE_STATUSBAR;
 
   return accessible;
@@ -148,26 +144,28 @@ gail_statusbar_ref_child (AtkObject          *obj,
 }
 
 static void
-gail_statusbar_real_init (GailWidget         *widget,
-                          GtkWidget          *gtk_widget)
+gail_statusbar_real_initialize (AtkObject *obj,
+                                gpointer  data)
 {
-  GailStatusbar *statusbar = GAIL_STATUSBAR (widget);
-  GailContainer *container = GAIL_CONTAINER (widget);
+  GailStatusbar *statusbar = GAIL_STATUSBAR (obj);
   GtkStatusbar *gtk_status_bar;
+  guint handler_id;
 
-  GAIL_WIDGET_CLASS (parent_class)->init (widget, gtk_widget);
+  ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
 
   /*
    * As we report the statusbar as having no children we are not interested
    * in add and remove signals
    */
-  g_signal_handler_disconnect (GTK_OBJECT (gtk_widget), container->add_handler);
-  g_signal_handler_disconnect (GTK_OBJECT (gtk_widget), container->remove_handler);
+  handler_id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (obj), "gail-add-handler-id"));
+  g_signal_handler_disconnect (data, handler_id);
+  handler_id = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (obj), "gail-remove-handler-id"));
+  g_signal_handler_disconnect (data, handler_id);
 
   /*
    * We get notified of changes to the label
    */
-  gtk_status_bar = GTK_STATUSBAR (gtk_widget);
+  gtk_status_bar = GTK_STATUSBAR (data);
   g_signal_connect (G_OBJECT (gtk_status_bar->label),
                     "notify",
                     G_CALLBACK (gail_statusbar_notify),
