@@ -433,13 +433,6 @@ gail_text_cell_get_default_attributes (AtkText	*text)
   widget = GTK_ACCESSIBLE (parent)->widget;
   layout = create_pango_layout (gtk_renderer, widget),
 
-  attrib_set = gail_misc_add_attribute (attrib_set,
-                                        ATK_TEXT_ATTR_JUSTIFICATION,
-     g_strdup (atk_text_attribute_get_value (ATK_TEXT_ATTR_JUSTIFICATION, 0)));
-  attrib_set = gail_misc_add_attribute (attrib_set,
-                                        ATK_TEXT_ATTR_WRAP_MODE,
-              g_strdup (atk_text_attribute_get_value (ATK_TEXT_ATTR_WRAP_MODE, 0)));
-
   attrib_set = gail_misc_get_default_attributes (attrib_set, 
                                                  layout,
                                                  widget);
